pub struct Extension { /* private fields */ }Expand description
A bundled Postgres extension that can be installed into a PGlite database.
Implementations
Sourceimpl Extension
impl Extension
Sourcepub const fn archive_name(self) -> &'static str
pub const fn archive_name(self) -> &'static str
Archive path inside the asset manifest.
Sourcepub const fn aot_name(self) -> Option<&'static str>
pub const fn aot_name(self) -> Option<&'static str>
AOT artifact key for the extension side module.
Sourcepub const fn native_module_file(self) -> Option<&'static str>
pub const fn native_module_file(self) -> Option<&'static str>
Native side-module file installed into /lib/postgresql, when the
extension has one.
Sourcepub const fn dependencies(self) -> &'static [&'static str]
pub const fn dependencies(self) -> &'static [&'static str]
SQL extension names that must be installed before this extension.