pub struct PgliteServerBuilder { /* private fields */ }Expand description
Builder for PgliteServer.
Implementations
Sourceimpl PgliteServerBuilder
impl PgliteServerBuilder
Sourcepub fn path(self, root: impl Into<PathBuf>) -> Self
pub fn path(self, root: impl Into<PathBuf>) -> Self
Serve a persistent database rooted at root.
Sourcepub fn temporary(self) -> Self
pub fn temporary(self) -> Self
Serve a temporary database cloned from the process-local template cache.
Sourcepub fn fresh_temporary(self) -> Self
pub fn fresh_temporary(self) -> Self
Serve a temporary database initialized without the template cache.
Sourcepub fn tcp(self, addr: SocketAddr) -> Self
pub fn tcp(self, addr: SocketAddr) -> Self
Bind the server to a TCP address.
Sourcepub fn unix(self, path: impl Into<PathBuf>) -> Self
pub fn unix(self, path: impl Into<PathBuf>) -> Self
Bind the server to a Unix-domain socket path.
Sourcepub fn start(self) -> Result<PgliteServer>
pub fn start(self) -> Result<PgliteServer>
Install the runtime if needed, initialize the cluster, and start serving.